use std::path::Path;

pub use ccutils::Result;

mod cli;
mod config;
use config::{Config, WebSycnConf};
mod syncer;

pub const MAX_TASKS: usize = 10;
pub const RETRIES: usize = 5;
pub const CONF: &str = "/etc/cuvars/cuweb-syncer";

pub fn cumain() -> Result<()> {
    let cli = cli::parse();

    // 设置日志级别
    match (cli.debug, cli.quiet) {
        (true, _) => std::env::set_var("RUST_LOG", "debug"),
        (false, true) => std::env::set_var("RUST_LOG", "error"),
        _ => {}
    }
    ccutils::set_up_logging()?;

    let config = {
        if cli.from.is_some() && cli.dest.is_some() {
            let mut config = Config::new();
            let websync_conf =
                WebSycnConf::new(cli.from.clone().unwrap(), cli.dest.clone().unwrap());
            config.inner.insert("Task".to_string(), websync_conf);
            config
        } else {
            let default = Path::new(CONF);
            let conf = if default.is_file() {
                CONF
            } else {
                "cuweb-syncer"
            };
            match Config::load(conf) {
                Ok(conf) => conf,
                Err(e) => {
                    panic!("Failed to load {conf}: {e}");
                }
            }
        }
    };

    let rt = ccutils::async_runtime()?;

    let _ = rt.block_on(syncer::run(&config))?;
    Ok(())
}
